"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const child_process = __importStar(require("child_process"));
function getImageNameWithTag(options) {
    return options.account !== ''
        ? `${options.account}/${options.imageName}:${options.tag}`
        : `${options.imageName}:${options.tag}`;
}
function buildDockerImage(imageNameWithTag, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        const child = child_process.spawn('docker', ['build', '-t', imageNameWithTag, '.'], {
            stdio: 'pipe',
        });
        child.stdout.on('data', (data) => {
            logger.info(data.toString());
        });
        child.stderr.on('data', (data) => {
            logger.error(data.toString());
        });
        return new Promise((resolve) => {
            child.on('close', (code) => {
                resolve();
            });
        });
    });
}
function publishDockerImage(imageNameWithTag, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        const child = child_process.spawn('docker', ['push', imageNameWithTag], {
            stdio: 'pipe',
        });
        child.stdout.on('data', (data) => {
            logger.info(data.toString());
        });
        child.stderr.on('data', (data) => {
            logger.error(data.toString());
        });
        return new Promise((resolve) => {
            child.on('close', (code) => {
                resolve();
            });
        });
    });
}
function run(options, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const imageNameWithTag = getImageNameWithTag(options);
            logger.info('🚧 Executing Docker Build...');
            yield buildDockerImage(imageNameWithTag, logger);
            logger.info('✔️ Docker Build was successfully');
            logger.info('🚀 Publishing image to registry');
            yield publishDockerImage(imageNameWithTag, logger);
            logger.info('🎊 Successfully published image. Have a nice day.');
        }
        catch (error) {
            logger.error('❌ An error occurred!');
            throw error;
        }
    });
}
exports.run = run;
//# sourceMappingURL=engine.js.map